@@ -1,5 +1,5 @@
 
-c5_bagger <- function(rs, control, ...) {
+c5_bagger <- function(rs, control, ..., call) {
 
   opt <- rlang::dots_list(...)
   mod_spec <- make_c5_spec(opt)
@@ -17,7 +17,7 @@ c5_bagger <- function(rs, control, ...) {
       control = control
     ))
 
-  rs <- check_for_disaster(rs)
+  rs <- check_for_disaster(rs, call = call)
 
   rs <- filter_rs(rs)
 
@@ -32,7 +32,7 @@ c5_bagger <- function(rs, control, ...) {
   if (control$reduce) {
     rs <-
       rs %>%
-      mutate(model = map(model, axe_C5))
+      dplyr::mutate(model = purrr::map(model, axe_C5))
   }
 
   list(model = rs, imp = imps)
