@@ -1,4 +1,5 @@
-bagger_bridge <- function(processed, weights, base_model, seed, times, control, cost, ...) {
+bagger_bridge <- function(processed, weights, base_model, seed, times, control,
+                          cost, ..., call = rlang::caller_env()) {
   validate_outcomes_are_univariate(processed$outcomes)
   if (base_model %in% c("C5.0")) {
     validate_outcomes_are_factors(processed$outcomes)
@@ -19,16 +20,16 @@ bagger_bridge <- function(processed, weights, base_model, seed, times, control,
   if (is.null(cost)) {
     res <- switch(
       base_model,
-      CART = cart_bagger(rs, control, ...),
-      C5.0 =   c5_bagger(rs, control, ...),
-      MARS = mars_bagger(rs, control, ...),
-      nnet = nnet_bagger(rs, control, ...)
+      CART = cart_bagger(rs, control, ..., call = call),
+      C5.0 =   c5_bagger(rs, control, ..., call = call),
+      MARS = mars_bagger(rs, control, ..., call = call),
+      nnet = nnet_bagger(rs, control, ..., call = call)
     )
   } else {
     res <- switch(
       base_model,
-      CART = cost_sens_cart_bagger(rs, control, cost, ...),
-      C5.0 =   cost_sens_c5_bagger(rs, control, cost, ...)
+      CART = cost_sens_cart_bagger(rs, control, cost, ..., call = call),
+      C5.0 =   cost_sens_c5_bagger(rs, control, cost, ..., call = call)
     )
   }
 
@@ -43,16 +44,3 @@ bagger_bridge <- function(processed, weights, base_model, seed, times, control,
     )
   res
 }
-
-validate_case_weights <- function(weights, data) {
-  if (is.null(weights)) {
-    return(invisible(NULL))
-  }
-  n <- nrow(data)
-  if (!is.vector(weights) || !is.numeric(weights) || length(weights) != n ||
-      any(weights < 0)) {
-    rlang::abort("'weights' should be a non-negative numeric vector with the same size as the data.")
-  }
-  invisible(NULL)
-}
-
