@@ -1,5 +1,5 @@
 
-cart_bagger <- function(rs, control, ...) {
+cart_bagger <- function(rs, control, ..., call) {
   opt <- rlang::dots_list(...)
   is_classif <- is.factor(rs$splits[[1]]$data$.outcome)
   mod_spec <- make_cart_spec(is_classif, opt)
@@ -19,7 +19,7 @@ cart_bagger <- function(rs, control, ...) {
       )
     )
 
-  rs <- check_for_disaster(rs)
+  rs <- check_for_disaster(rs, call = call)
 
   rs <- filter_rs(rs)
 
@@ -34,7 +34,7 @@ cart_bagger <- function(rs, control, ...) {
   if (control$reduce) {
     rs <-
       rs %>%
-      mutate(model = map(model, axe_cart))
+      dplyr::mutate(model = purrr::map(model, axe_cart))
   }
 
   list(model = rs, imp = imps)
