@@ -1,9 +1,10 @@
-cost_matrix <- function(x, lvl, truth_is_row = TRUE) {
+cost_matrix <- function(x, lvl, truth_is_row = TRUE, call = rlang::caller_env()) {
   if (is.matrix(x)) {
 
   } else {
     if (length(lvl) != 2) {
-      rlang::abort("`cost` can only be a scalar when there are two levels.")
+      cli::cli_abort("{.arg cost} can only be a scalar when there are two
+                     levels.", call = call)
     } else {
       x0 <- x
       x <- matrix(1, ncol = 2, nrow = 2)
@@ -19,14 +20,14 @@ cost_matrix <- function(x, lvl, truth_is_row = TRUE) {
   x
 }
 
-cost_sens_cart_bagger <- function(rs, control, cost, ...) {
+cost_sens_cart_bagger <- function(rs, control, cost, ..., call = rlang::caller_env()) {
 
   # capture dots
   opt <- rlang::dots_list(...)
   nms <- names(opt)
   lvl <- levels(rs$splits[[1]]$data$.outcome)
 
-  cost <- cost_matrix(cost, lvl)
+  cost <- cost_matrix(cost, lvl, call = call)
 
   # Attach cost matrix to parms = list(loss) but first
   # check existing options passed by user for loss
@@ -36,22 +37,22 @@ cost_sens_cart_bagger <- function(rs, control, cost, ...) {
     opt$parms <- list(loss = cost)
   }
 
-  cart_bagger(rs = rs, control = control, !!!opt)
+  cart_bagger(rs = rs, control = control, call = call, !!!opt)
 }
 
 
 
-cost_sens_c5_bagger <- function(rs, control, cost, ...) {
+cost_sens_c5_bagger <- function(rs, control, cost, ..., call = rlang::caller_env()) {
 
   # capture dots
   opt <- rlang::dots_list(...)
   nms <- names(opt)
   lvl <- levels(rs$splits[[1]]$data$.outcome)
 
-  cost <- cost_matrix(cost, lvl, truth_is_row = FALSE)
+  cost <- cost_matrix(cost, lvl, truth_is_row = FALSE, call = call)
 
   # Attach cost matrix to options
   opt$costs <-  cost
 
-  c5_bagger(rs = rs, control = control, !!!opt)
+  c5_bagger(rs = rs, control = control, call = call, !!!opt)
 }
